| Title: | Client for Central Bank APIs |
|---|---|
| Description: | A client for retrieving data and metadata from central bank APIs including 'Banco de España' (BdE), 'Banco de Portugal' (BdP), 'Bank for International Settlements' (BIS), 'Bank of Canada' (BoC), 'Bank of England' (BoE), 'Bank of Japan' (BoJ), 'Banque de France' (BdF), 'Czech National Bank' (CNB), 'Deutsche Bundesbank' (BBk), 'European Central Bank' (ECB), 'National Bank of Poland' (NBP), 'Norges Bank' (NoB), 'Oesterreichische Nationalbank' (OeNB), 'Sveriges Riksbank' (SRb), and 'Swiss National Bank' (SNB). |
| Authors: | Maximilian Mücke [aut, cre] (ORCID: <https://orcid.org/0009-0000-9432-9795>) |
| Maintainer: | Maximilian Mücke <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.10.0.9000 |
| Built: | 2026-06-02 10:23:39 UTC |
| Source: | https://github.com/m-muecke/bbk |
Retrieve time series data from the Bundesbank SDMX Web Service.
bbk_data( flow, key = NULL, start_period = NULL, end_period = NULL, first_n = NULL, last_n = NULL, updated_after = NULL )bbk_data( flow, key = NULL, start_period = NULL, end_period = NULL, first_n = NULL, last_n = NULL, updated_after = NULL )
flow |
( |
key |
( |
start_period |
(
If |
end_period |
( |
first_n |
( |
last_n |
( |
updated_after |
( |
A data.table::data.table() with the requested data.
Other data:
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
# fetch all data for a given flow and key data <- bbk_data("BBSIS", "D.I.ZAR.ZI.EUR.S1311.B.A604.R10XX.R.A.A._Z._Z.A") head(data) # fetch data for multiple keys data <- bbk_data("BBEX3", c("M.ISK.EUR", "USD.CA.AC.A01")) head(data) # specified period (start date-end date) for daily data data <- bbk_data( "BBSIS", "D.I.ZAR.ZI.EUR.S1311.B.A604.R10XX.R.A.A._Z._Z.A", start_period = "2020-01-01", end_period = "2020-08-01" ) head(data) # or only specify the start date data <- bbk_data( "BBSIS", "D.I.ZAR.ZI.EUR.S1311.B.A604.R10XX.R.A.A._Z._Z.A", start_period = "2024-04-01" ) head(data)# fetch all data for a given flow and key data <- bbk_data("BBSIS", "D.I.ZAR.ZI.EUR.S1311.B.A604.R10XX.R.A.A._Z._Z.A") head(data) # fetch data for multiple keys data <- bbk_data("BBEX3", c("M.ISK.EUR", "USD.CA.AC.A01")) head(data) # specified period (start date-end date) for daily data data <- bbk_data( "BBSIS", "D.I.ZAR.ZI.EUR.S1311.B.A604.R10XX.R.A.A._Z._Z.A", start_period = "2020-01-01", end_period = "2020-08-01" ) head(data) # or only specify the start date data <- bbk_data( "BBSIS", "D.I.ZAR.ZI.EUR.S1311.B.A604.R10XX.R.A.A._Z._Z.A", start_period = "2024-04-01" ) head(data)
Retrieve the dimension structure for a given dataflow from the Bundesbank SDMX Web Service.
bbk_dimension(id)bbk_dimension(id)
id |
( |
A data.table::data.table() with columns:
id |
The dimension id (e.g., |
position |
The position of the dimension in the series key |
codelist |
The id of the associated codelist |
Other metadata:
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
bbk_dimension("BBK_ERX")bbk_dimension("BBK_ERX")
Retrieve metadata from the Bundesbank time series database via the SDMX Web Service.
bbk_metadata(type, id = NULL, lang = "en")bbk_metadata(type, id = NULL, lang = "en")
type |
( |
id |
( |
lang |
( |
A data.table::data.table() with the requested metadata.
The columns are:
id |
The id of the metadata |
name |
The name of the metadata |
Other metadata:
bbk_dimension(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
bbk_metadata("datastructure") bbk_metadata("dataflow", "BBSIS") bbk_metadata("codelist", "CL_BBK_ACIP_ASSET_LIABILITY") bbk_metadata("concept", "CS_BBK_BSPL")bbk_metadata("datastructure") bbk_metadata("dataflow", "BBSIS") bbk_metadata("codelist", "CL_BBK_ACIP_ASSET_LIABILITY") bbk_metadata("concept", "CS_BBK_BSPL")
Retrieve a single series by its key via the Bundesbank SDMX Web Service.
bbk_series(key)bbk_series(key)
key |
( |
A data.table::data.table() with the requested data.
bbk_data() for an endpoint with more options.
Other data:
bbk_data(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
bbk_series("BBEX3.M.DKK.EUR.BB.AC.A01") bbk_series("BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B") bbk_series("BBBK11.D.TTA000")bbk_series("BBEX3.M.DKK.EUR.BB.AC.A01") bbk_series("BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B") bbk_series("BBBK11.D.TTA000")
Retrieve time series data from the BdE statistics API.
bde_data(key, time_range = NULL, lang = "en")bde_data(key, time_range = NULL, lang = "en")
key |
( |
time_range |
(
If |
lang |
( |
You can search for the series codes in the BIEST application or in the tables published by the Banco de España.
A data.table::data.table() with the requested data.
https://www.bde.es/webbe/en/estadisticas/recursos/api-estadisticas-bde.html
Other data:
bbk_data(),
bbk_series(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
bde_data("D_1NBAF472", time_range = "30M") bde_data(c("DTNPDE2010_P0000P_PS_APU", "DTNSEC2010_S0000P_APU_SUMAMOVIL"), time_range = "MAX") bde_data("DEEQ.N.ES.W1.S1.S1.T.B.G._Z._Z._Z.EUR._T._X.N.ALL", time_range = 2024)bde_data("D_1NBAF472", time_range = "30M") bde_data(c("DTNPDE2010_P0000P_PS_APU", "DTNSEC2010_S0000P_APU_SUMAMOVIL"), time_range = "MAX") bde_data("DEEQ.N.ES.W1.S1.S1.T.B.G._Z._Z._Z.EUR._T._X.N.ALL", time_range = 2024)
Retrieve the most recently published value for one or more series from the BdE statistics API.
bde_latest(key, lang = "en")bde_latest(key, lang = "en")
key |
( |
lang |
( |
A data.table::data.table() with the latest observation per series.
https://www.bde.es/webbe/en/estadisticas/recursos/api-estadisticas-bde.html
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
bde_latest("D_1NBAF472") bde_latest(c("D_1NBAF472", "DTNPDE2010_P0000P_PS_APU"))bde_latest("D_1NBAF472") bde_latest(c("D_1NBAF472", "DTNPDE2010_P0000P_PS_APU"))
Fetch Banque de France (BdF) codelists
bdf_codelist(..., lang = "en")bdf_codelist(..., lang = "en")
... |
( |
lang |
( |
A data.table::data.table() with the requested data.
https://webstat.banque-france.fr/en/pages/guide-migration-api/
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
## Not run: bdf_codelist() # filter for a specific codelist bdf_codelist(where = "codelist_id = 'CL_FREQ'") ## End(Not run)## Not run: bdf_codelist() # filter for a specific codelist bdf_codelist(where = "codelist_id = 'CL_FREQ'") ## End(Not run)
Retrieve time series data from the BdF Webstat API.
bdf_data( ..., key = NULL, start_date = NULL, end_date = NULL, lang = "en", api_key = bdf_key() )bdf_data( ..., key = NULL, start_date = NULL, end_date = NULL, lang = "en", api_key = bdf_key() )
... |
( |
key |
( |
start_date |
( |
end_date |
( |
lang |
( |
api_key |
( |
A data.table::data.table() with the requested data.
https://webstat.banque-france.fr/en/pages/guide-migration-api/
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
## Not run: bdf_data(key = "CONJ2.M.R24.T.SM.0RG24.EFTPM100.10") # inflation rate bdf_data(key = "ICP.M.FR.N.000000.4.ANR") # or with a date filter bdf_data(key = "ICP.M.FR.N.000000.4.ANR", start_date = "2025-01-01", end_date = "2025-06-30") # advanced filter with where clause bdf_data(key = "ICP.M.FR.N.000000.4.ANR", where = "time_period_start >= date'2025-01-01'") ## End(Not run)## Not run: bdf_data(key = "CONJ2.M.R24.T.SM.0RG24.EFTPM100.10") # inflation rate bdf_data(key = "ICP.M.FR.N.000000.4.ANR") # or with a date filter bdf_data(key = "ICP.M.FR.N.000000.4.ANR", start_date = "2025-01-01", end_date = "2025-06-30") # advanced filter with where clause bdf_data(key = "ICP.M.FR.N.000000.4.ANR", where = "time_period_start >= date'2025-01-01'") ## End(Not run)
Fetch Banque de France (BdF) datasets
bdf_dataset(..., lang = "en")bdf_dataset(..., lang = "en")
... |
( |
lang |
( |
A data.table::data.table() with the requested data.
https://webstat.banque-france.fr/en/pages/guide-migration-api/
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
## Not run: bdf_dataset() # structure of a dataset bdf_dataset(where = "dataset_id = 'CONJ2'") ## End(Not run)## Not run: bdf_dataset() # structure of a dataset bdf_dataset(where = "dataset_id = 'CONJ2'") ## End(Not run)
Retrieve the dimension structure for a given dataset from the BdF Webstat API.
bdf_dimension(dataset_id, lang = "en", api_key = bdf_key())bdf_dimension(dataset_id, lang = "en", api_key = bdf_key())
dataset_id |
( |
lang |
( |
api_key |
( |
A data.table::data.table() with columns:
id |
The dimension id (e.g., |
position |
The position of the dimension in the series key |
codelist |
The id of the associated codelist |
https://webstat.banque-france.fr/en/pages/guide-migration-api/
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
## Not run: bdf_dimension("CONJ2") ## End(Not run)## Not run: bdf_dimension("CONJ2") ## End(Not run)
Retrieve time series data from the BPstat API.
bdp_data( domain_id, dataset_id, series_ids = NULL, start_date = NULL, end_date = NULL, last_n = NULL, updated_after = NULL, lang = "en" )bdp_data( domain_id, dataset_id, series_ids = NULL, start_date = NULL, end_date = NULL, last_n = NULL, updated_after = NULL, lang = "en" )
domain_id |
( |
dataset_id |
( |
series_ids |
( |
start_date |
( |
end_date |
( |
last_n |
( |
updated_after |
( |
lang |
( |
The BPstat API uses a two-step workflow: first look up the series metadata with
bdp_series() to find the domain_id and dataset_id, then use those to fetch the actual
observations.
You can browse available series at the BPstat portal.
A data.table::data.table() with the requested data.
https://bpstat.bportugal.pt/data/docs
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
# Portuguese GDP (annual, current prices) bdp_data(54L, "ce3e4e50cda325537eff729ef64037cd", series_ids = 12518356L)# Portuguese GDP (annual, current prices) bdp_data(54L, "ce3e4e50cda325537eff729ef64037cd", series_ids = 12518356L)
Retrieve the list of datasets for a given domain from the BPstat API.
bdp_dataset(domain_id, lang = "en")bdp_dataset(domain_id, lang = "en")
domain_id |
( |
lang |
( |
A data.table::data.table() with available datasets.
https://bpstat.bportugal.pt/data/docs
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
bdp_dataset(54L)bdp_dataset(54L)
Retrieve the list of dimensions for a given domain, or the categories within a single dimension.
bdp_dimension(domain_id, dimension_id = NULL, lang = "en")bdp_dimension(domain_id, dimension_id = NULL, lang = "en")
domain_id |
( |
dimension_id |
( |
lang |
( |
A data.table::data.table() with dimensions or categories.
https://bpstat.bportugal.pt/data/docs
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
bdp_dimension(54L)bdp_dimension(54L)
Retrieve the list of available statistical domains from the BPstat API, or details for a single domain.
bdp_domain(domain_id = NULL, lang = "en")bdp_domain(domain_id = NULL, lang = "en")
domain_id |
( |
lang |
( |
A data.table::data.table() with available domains.
https://bpstat.bportugal.pt/data/docs
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
bdp_domain()bdp_domain()
Retrieve metadata for one or more series from the BPstat API. This is useful to discover the
domain_id and dataset_id needed for bdp_data().
bdp_series(series_ids, lang = "en")bdp_series(series_ids, lang = "en")
series_ids |
( |
lang |
( |
A data.table::data.table() with series metadata including domain_id and
dataset_id.
https://bpstat.bportugal.pt/data/docs
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
bdp_series(12518356L)bdp_series(12518356L)
Retrieve time series data from the BIS SDMX Web Service.
bis_data( flow, key = NULL, start_period = NULL, end_period = NULL, first_n = NULL, last_n = NULL, updated_after = NULL )bis_data( flow, key = NULL, start_period = NULL, end_period = NULL, first_n = NULL, last_n = NULL, updated_after = NULL )
flow |
( |
key |
( |
start_period |
(
If |
end_period |
( |
first_n |
( |
last_n |
( |
updated_after |
( |
A data.table::data.table() with the requested data.
https://stats.bis.org/api-doc/v1/
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
# fetch Swiss central bank policy rate bis_data("WS_CBPOL", "M.CH", last_n = 5L) # fetch effective exchange rates bis_data("WS_EER", "M.N.B.CH", start_period = "2020-01")# fetch Swiss central bank policy rate bis_data("WS_CBPOL", "M.CH", last_n = 5L) # fetch effective exchange rates bis_data("WS_EER", "M.N.B.CH", start_period = "2020-01")
Retrieve the dimension structure for a given dataflow from the BIS SDMX Web Service.
bis_dimension(id)bis_dimension(id)
id |
( |
A data.table::data.table() with columns:
id |
The dimension id (e.g., |
position |
The position of the dimension in the series key |
codelist |
The id of the associated codelist (e.g., |
https://stats.bis.org/api-doc/v1/
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
bis_dimension("BIS_CBPOL")bis_dimension("BIS_CBPOL")
Retrieve metadata from the BIS SDMX Web Service.
bis_metadata(type, id = NULL)bis_metadata(type, id = NULL)
type |
( |
id |
( |
A data.table::data.table() with the requested metadata.
https://stats.bis.org/api-doc/v1/
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
bis_metadata("dataflow") bis_metadata("datastructure", "BIS_CBPOL") bis_metadata("codelist", "CL_FREQ")bis_metadata("dataflow") bis_metadata("datastructure", "BIS_CBPOL") bis_metadata("codelist", "CL_FREQ")
Access all available series or groups from the Bank of Canada Valet API.
boc_catalog(type = "groups")boc_catalog(type = "groups")
type |
( |
A data.table::data.table() with the requested data.
https://www.bankofcanada.ca/valet/docs
## Not run: catalog <- boc_catalog() head(catalog) # filter for effective exchange rate series dt <- catalog[grepl("CEER", label)] head(dt) ## End(Not run)## Not run: catalog <- boc_catalog() head(catalog) # filter for effective exchange rate series dt <- catalog[grepl("CEER", label)] head(dt) ## End(Not run)
Retrieve time series data from the Bank of Canada Valet API.
boc_data( group_name = NULL, series_name = NULL, start_date = NULL, end_date = NULL )boc_data( group_name = NULL, series_name = NULL, start_date = NULL, end_date = NULL )
group_name |
( |
series_name |
( |
start_date |
( |
end_date |
( |
A data.table::data.table() with the requested data.
https://www.bankofcanada.ca/valet/docs
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
## Not run: # fetch all data for a single group dt <- boc_data(group_name = "FX_RATES_DAILY") head(dt) # or for multiple series ids dt <- boc_data( series_name = c("FXUSDCAD", "FXEURCAD"), start_date = "2023-01-23", end_date = "2023-07-19" ) head(dt) ## End(Not run)## Not run: # fetch all data for a single group dt <- boc_data(group_name = "FX_RATES_DAILY") head(dt) # or for multiple series ids dt <- boc_data( series_name = c("FXUSDCAD", "FXEURCAD"), start_date = "2023-01-23", end_date = "2023-07-19" ) head(dt) ## End(Not run)
Fetch the latest or historical foreign exchange reference rates from the Bank of Canada (BoC).
boc_fx_rates(start_date = NULL, end_date = NULL, limit = NULL, skip = NULL)boc_fx_rates(start_date = NULL, end_date = NULL, limit = NULL, skip = NULL)
start_date |
( |
end_date |
( |
limit |
( |
skip |
( |
The recorded rates indicate the number of Canadian dollars required to buy a single unit of the foreign currency. New rates are released by the Bank of Canada (BoC) daily at 4:30 pm. The Canada Border Services (CBSA) retrieves these updates between 4:30 pm and 5 pm ET.
BoC provides 23 foreign exchange rates. All other rates are maintained by the CBSA.
Exchange rates from the BoC are updated daily in the system while other exchange rates are updated by the CBSA at set intervals. The updated rates are available for retrieval between 7 pm and 11:59 pm ET.
As BoC publishes exchange rates every business day, it is recommended that exchange rate data be retrieved on a daily basis. This retrieval should occur after 7 pm ET to ensure retrieval of the latest updates.
A data.table::data.table() with the exchange rates.
https://www.cbsa-asfc.gc.ca/eservices/api/er-tc-api-eng.html
# fetch latest exchange rates boc_fx_rates() # fetch historical exchange rates boc_fx_rates(start_date = "2021-10-22", end_date = "2021-10-23", limit = 10, skip = 2)# fetch latest exchange rates boc_fx_rates() # fetch historical exchange rates boc_fx_rates(start_date = "2021-10-22", end_date = "2021-10-23", limit = 10, skip = 2)
Fetch Bank of Canada (BoC) metadata (details)
boc_metadata(group_name = NULL, series_name = NULL)boc_metadata(group_name = NULL, series_name = NULL)
group_name |
( |
series_name |
( |
A data.table::data.table() with the requested data.
https://www.bankofcanada.ca/valet/docs
## Not run: boc_metadata(group_name = "FX_RATES_DAILY") boc_metadata(series_name = "FXUSDCAD") ## End(Not run)## Not run: boc_metadata(group_name = "FX_RATES_DAILY") boc_metadata(series_name = "FXUSDCAD") ## End(Not run)
Retrieve time series data from the BoE database.
boe_data(key, start_date, end_date = Sys.Date())boe_data(key, start_date, end_date = Sys.Date())
key |
( |
start_date |
( |
end_date |
( |
A data.table::data.table() with the requested data.
https://www.bankofengland.co.uk/boeapps/database
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
# Bank Rate boe_data("IUDBEDR", "2015-01-01") # SONIA daily rate boe_data("IUDSOIA", "2015-01-01") # 10-year nominal par yield boe_data("IUDMNPY", "2015-01-01") # multiple series boe_data(c("IUMABEDR", "IUALBEDR"), "2015-01-01")# Bank Rate boe_data("IUDBEDR", "2015-01-01") # SONIA daily rate boe_data("IUDSOIA", "2015-01-01") # 10-year nominal par yield boe_data("IUDMNPY", "2015-01-01") # multiple series boe_data(c("IUMABEDR", "IUALBEDR"), "2015-01-01")
Retrieve time series data from the Bank of Japan Statistics API.
boj_data(db, code, start_date = NULL, end_date = NULL, lang = "en")boj_data(db, code, start_date = NULL, end_date = NULL, lang = "en")
db |
( |
code |
( |
start_date |
( |
end_date |
( |
lang |
( |
A data.table::data.table() with the requested data.
https://www.stat-search.boj.or.jp/index_en.html
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
# fetch USD/JPY exchange rate boj_data("FM08", "FXERD01", start_date = "202401") # fetch multiple exchange rates boj_data("FM08", c("FXERD01", "FXERD02"), start_date = "202401")# fetch USD/JPY exchange rate boj_data("FM08", "FXERD01", start_date = "202401") # fetch multiple exchange rates boj_data("FM08", c("FXERD01", "FXERD02"), start_date = "202401")
Retrieve series metadata from the Bank of Japan Statistics API.
boj_metadata(db, lang = "en")boj_metadata(db, lang = "en")
db |
( |
lang |
( |
A data.table::data.table() with the requested metadata.
https://www.stat-search.boj.or.jp/index_en.html
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
boj_metadata("FM08")boj_metadata("FM08")
bbk_cache_dir() returns the path where cached API responses are stored.
bbk_cache_clear() clears all cached responses.
bbk_cache_dir() bbk_cache_clear()bbk_cache_dir() bbk_cache_clear()
The cache is only used when enabled with options(bbk.cache = TRUE).
Cached responses are stored for 1 day by default, but this can be customized with
options(bbk.cache_max_age = seconds).
## Not run: # enable caching options(bbk.cache = TRUE) # view cache location bbk_cache_dir() # clear the cache bbk_cache_clear() ## End(Not run)## Not run: # enable caching options(bbk.cache = TRUE) # view cache location bbk_cache_dir() # clear the cache bbk_cache_clear() ## End(Not run)
Retrieve time series observations from the CNB ARAD database. ARAD is the CNB's full statistical database, covering monetary, financial-market, balance-of-payments, and government finance statistics. Access requires an API key, which can be generated from a free account at https://www.cnb.cz/arad/.
cnb_data( indicator_id = NULL, set_id = NULL, base_id = NULL, selection_id = NULL, start_period = NULL, end_period = NULL, snapshot_id = NULL, api_key = cnb_arad_key() )cnb_data( indicator_id = NULL, set_id = NULL, base_id = NULL, selection_id = NULL, start_period = NULL, end_period = NULL, snapshot_id = NULL, api_key = cnb_arad_key() )
indicator_id |
( |
set_id |
( |
base_id |
( |
selection_id |
( |
start_period |
( |
end_period |
( |
snapshot_id |
( |
api_key |
( |
A data.table::data.table() with columns:
date |
The observation period |
indicator_id |
The indicator identifier |
snapshot_id |
The snapshot identifier, or |
value |
The observation value |
https://www.cnb.cz/docs/arad20/dokumentace/arad_rest_api_cs.pdf
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
## Not run: # a single indicator over 24 months cnb_data("SMV5M603", start_period = "2023-01-01") # every indicator in a set cnb_data(set_id = "1058") ## End(Not run)## Not run: # a single indicator over 24 months cnb_data("SMV5M603", start_period = "2023-01-01") # every indicator in a set cnb_data(set_id = "1058") ## End(Not run)
Retrieve the dimension structure of indicators from the CNB ARAD database, returning one row per indicator dimension.
cnb_dimension( indicator_id = NULL, set_id = NULL, base_id = NULL, selection_id = NULL, lang = "en", api_key = cnb_arad_key() )cnb_dimension( indicator_id = NULL, set_id = NULL, base_id = NULL, selection_id = NULL, lang = "en", api_key = cnb_arad_key() )
indicator_id |
( |
set_id |
( |
base_id |
( |
selection_id |
( |
lang |
( |
api_key |
( |
A data.table::data.table() with columns including indicator_id, base_code,
base_name, dim_code, dim_name, dim_value_code, dim_value_name, and dim_rank.
https://www.cnb.cz/docs/arad20/dokumentace/arad_rest_api_cs.pdf
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
## Not run: cnb_dimension(indicator_id = "MIRFMDF12ERATPECD") ## End(Not run)## Not run: cnb_dimension(indicator_id = "MIRFMDF12ERATPECD") ## End(Not run)
Retrieve the central bank exchange rate fixing (Czech koruna against foreign currencies) from the CNB API.
cnb_fx_rates(date = NULL, year = NULL, lang = "EN")cnb_fx_rates(date = NULL, year = NULL, lang = "EN")
date |
( |
year |
( |
lang |
( |
A data.table::data.table() with the requested exchange rates. The rate is the amount
of Czech koruna per amount units of the foreign currency.
https://api.cnb.cz/cnbapi/swagger-ui.html
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
# latest fixing for all currencies cnb_fx_rates() # all fixings for a given year cnb_fx_rates(year = 2024L)# latest fixing for all currencies cnb_fx_rates() # all fixings for a given year cnb_fx_rates(year = 2024L)
Retrieve the available indicators and their attributes from the CNB ARAD database. Use this to
discover indicator identifiers for cnb_data().
cnb_indicators( indicator_id = NULL, set_id = NULL, base_id = NULL, selection_id = NULL, lang = "en", api_key = cnb_arad_key() )cnb_indicators( indicator_id = NULL, set_id = NULL, base_id = NULL, selection_id = NULL, lang = "en", api_key = cnb_arad_key() )
indicator_id |
( |
set_id |
( |
base_id |
( |
selection_id |
( |
lang |
( |
api_key |
( |
A data.table::data.table() with one row per indicator and columns including
indicator_id, indicator_name, frequency_code, frequency_name, unit_mult_code,
unit_mult_name, and unit.
https://www.cnb.cz/docs/arad20/dokumentace/arad_rest_api_cs.pdf
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
## Not run: cnb_indicators(set_id = "1058") ## End(Not run)## Not run: cnb_indicators(set_id = "1058") ## End(Not run)
Retrieve the Prague Interbank Offered Rate (PRIBOR) reference rates for all maturities from the CNB API.
cnb_pribor(date = NULL, year = NULL)cnb_pribor(date = NULL, year = NULL)
date |
( |
year |
( |
A data.table::data.table() with the requested rates. The period column holds the
maturity (e.g. "ONE_DAY", "THREE_MONTH") and pribor the rate in percent.
https://api.cnb.cz/cnbapi/swagger-ui.html
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
# latest rates for all maturities cnb_pribor() # all rates for a given year cnb_pribor(year = 2024L)# latest rates for all maturities cnb_pribor() # all rates for a given year cnb_pribor(year = 2024L)
Retrieve the list of available snapshots (data vintages) from the CNB ARAD database. Snapshot ids
can be passed to the snapshot_id argument of cnb_data().
cnb_snapshots(lang = "en", api_key = cnb_arad_key())cnb_snapshots(lang = "en", api_key = cnb_arad_key())
lang |
( |
api_key |
( |
A data.table::data.table() with columns snapshot_id and snapshot_name.
https://www.cnb.cz/docs/arad20/dokumentace/arad_rest_api_cs.pdf
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
## Not run: cnb_snapshots() ## End(Not run)## Not run: cnb_snapshots() ## End(Not run)
Retrieve the placement of indicators within the ARAD topic tree.
cnb_tree( indicator_id = NULL, set_id = NULL, base_id = NULL, selection_id = NULL, lang = "en", api_key = cnb_arad_key() )cnb_tree( indicator_id = NULL, set_id = NULL, base_id = NULL, selection_id = NULL, lang = "en", api_key = cnb_arad_key() )
indicator_id |
( |
set_id |
( |
base_id |
( |
selection_id |
( |
lang |
( |
api_key |
( |
A data.table::data.table() with columns indicator_id and path, where path is the
slash-separated location of the indicator in the ARAD tree.
https://www.cnb.cz/docs/arad20/dokumentace/arad_rest_api_cs.pdf
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
## Not run: cnb_tree(indicator_id = "MIRFMDF12ERATPECD") ## End(Not run)## Not run: cnb_tree(indicator_id = "MIRFMDF12ERATPECD") ## End(Not run)
Retrieve time series data from the ECB SDMX Web Service.
ecb_data( flow, key = NULL, start_period = NULL, end_period = NULL, first_n = NULL, last_n = NULL, updated_after = NULL )ecb_data( flow, key = NULL, start_period = NULL, end_period = NULL, first_n = NULL, last_n = NULL, updated_after = NULL )
flow |
( |
key |
( |
start_period |
(
If |
end_period |
( |
first_n |
( |
last_n |
( |
updated_after |
( |
A data.table::data.table() with the requested data.
https://data.ecb.europa.eu/help/api/data
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
# fetch US dollar/Euro exchange rate ecb_data("EXR", "D.USD.EUR.SP00.A") # fetch data for multiple keys ecb_data("EXR", c("D.USD", "JPY.EUR.SP00.A"))# fetch US dollar/Euro exchange rate ecb_data("EXR", "D.USD.EUR.SP00.A") # fetch data for multiple keys ecb_data("EXR", c("D.USD", "JPY.EUR.SP00.A"))
Retrieve the dimension structure for a given dataflow from the ECB SDMX Web Service.
ecb_dimension(id)ecb_dimension(id)
id |
( |
A data.table::data.table() with columns:
id |
The dimension id (e.g., |
position |
The position of the dimension in the series key |
codelist |
The id of the associated codelist (e.g., |
https://data.ecb.europa.eu/help/api/metadata
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
ecb_dimension("ECB_EXR1")ecb_dimension("ECB_EXR1")
Fetch the latest or historical Euro foreign exchange reference rates from the European Central Bank (ECB).
ecb_fx_rates(x = "latest") ecb_euro_rates(x = "latest")ecb_fx_rates(x = "latest") ecb_euro_rates(x = "latest")
x |
( |
Note you can achieve the same by calling the ecb_data() function with the right
parameters for each currency.
The reference rates are usually updated at around 16:00 CET every working day, except on TARGET closing days.
They are based on the daily concertation procedure between central banks across Europe, which normally takes place around 14:10 CET. The reference rates are published for information purposes only. Using the rates for transaction purposes is strongly discouraged.
A data.table::data.table() with the exchange rates.
ecb_fx_rates()ecb_fx_rates()
Retrieve metadata from the ECB time series database via the SDMX Web Service.
ecb_metadata(type, agency = NULL, id = NULL)ecb_metadata(type, agency = NULL, id = NULL)
type |
( |
agency |
( |
id |
( |
A data.table::data.table() with the requested metadata.
The columns are:
agency |
The agency of the metadata |
id |
The id of the metadata |
name |
The name of the metadata |
https://data.ecb.europa.eu/help/api/metadata
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
ecb_metadata("datastructure") ecb_metadata("datastructure", "ECB") ecb_metadata("datastructure", "ECB", "ECB_EXR1") ecb_metadata("datastructure", id = "ECB_EXR1")ecb_metadata("datastructure") ecb_metadata("datastructure", "ECB") ecb_metadata("datastructure", "ECB", "ECB_EXR1") ecb_metadata("datastructure", id = "ECB_EXR1")
Retrieve foreign currency exchange rates from the NBP Web API.
nbp_fx_rates( table, code = NULL, start_date = NULL, end_date = NULL, last_n = NULL )nbp_fx_rates( table, code = NULL, start_date = NULL, end_date = NULL, last_n = NULL )
table |
( |
code |
( |
start_date |
( |
end_date |
( |
last_n |
( |
A data.table::data.table() with exchange rates.
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
nbp_fx_rates("a", "eur")nbp_fx_rates("a", "eur")
Retrieve the price of gold from the NBP Web API.
nbp_gold(start_date = NULL, end_date = NULL, last_n = NULL)nbp_gold(start_date = NULL, end_date = NULL, last_n = NULL)
start_date |
( |
end_date |
( |
last_n |
( |
A data.table::data.table() with gold prices.
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
nbp_gold(last_n = 10L)nbp_gold(last_n = 10L)
Retrieve time series data from the Norges Bank SDMX Web Service.
nob_data( flow, key = NULL, start_period = NULL, end_period = NULL, first_n = NULL, last_n = NULL )nob_data( flow, key = NULL, start_period = NULL, end_period = NULL, first_n = NULL, last_n = NULL )
flow |
( |
key |
( |
start_period |
( |
end_period |
( |
first_n |
( |
last_n |
( |
A data.table::data.table() with the requested data.
https://www.norges-bank.no/en/topics/Statistics/open-data/
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
# fetch USD/NOK exchange rate nob_data("EXR", "B.USD.NOK.SP", last_n = 5L) # fetch multiple exchange rates nob_data("EXR", "B.USD+EUR+GBP.NOK.SP", start_period = "2024-01-01") # fetch policy rate nob_data("IR", last_n = 5L)# fetch USD/NOK exchange rate nob_data("EXR", "B.USD.NOK.SP", last_n = 5L) # fetch multiple exchange rates nob_data("EXR", "B.USD+EUR+GBP.NOK.SP", start_period = "2024-01-01") # fetch policy rate nob_data("IR", last_n = 5L)
Retrieve the dimension structure for a given dataflow from the Norges Bank SDMX Web Service.
nob_dimension(id)nob_dimension(id)
id |
( |
A data.table::data.table() with columns:
id |
The dimension id (e.g., |
position |
The position of the dimension in the series key |
codelist |
The id of the associated codelist (e.g., |
https://www.norges-bank.no/en/topics/Statistics/open-data/
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
nob_dimension("DSD_EXR")nob_dimension("DSD_EXR")
Retrieve metadata from the Norges Bank SDMX Web Service.
nob_metadata(type, id = NULL, lang = "en")nob_metadata(type, id = NULL, lang = "en")
type |
( |
id |
( |
lang |
( |
A data.table::data.table() with the requested metadata.
https://www.norges-bank.no/en/topics/Statistics/open-data/
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
nob_metadata("dataflow") nob_metadata("datastructure") nob_metadata("codelist", "CL_CURRENCY")nob_metadata("dataflow") nob_metadata("datastructure") nob_metadata("codelist", "CL_CURRENCY")
Retrieve time series data from the OeNB Web Service.
onb_data( hier_id, key, ..., start_period = NULL, end_period = NULL, freq = NULL, lang = "en" )onb_data( hier_id, key, ..., start_period = NULL, end_period = NULL, freq = NULL, lang = "en" )
hier_id |
( |
key |
( |
... |
( |
start_period |
( |
end_period |
( |
freq |
( |
lang |
( |
A data.table::data.table() with the requested data.
https://www.oenb.at/en/Statistics/User-Defined-Tables/webservice.html
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
snb_data(),
srb_cross_rates(),
srb_data()
onb_data(hier_id = 11, key = "VDBFKBSC217000") # Loans to euro area residents, since 2000: onb_data(hier_id = 11, key = "VDBFKBSC217000", start_period = "2000-01-01") # Austrian imports and exports of goods from/to Germany, 2002–2012, annual frequency: onb_data(hier_id = 901, key = "VDBQZA1000", start_period = 2002, end_period = 2012, freq = "A") # Number of Austrian banks' subsidiaries abroad and in the EU, from 2005, semiannual: onb_data( hier_id = 321, key = c("VDBKISDANZTAU", "VDBKISDANZTEU"), start_period = 200501, freq = "H" )onb_data(hier_id = 11, key = "VDBFKBSC217000") # Loans to euro area residents, since 2000: onb_data(hier_id = 11, key = "VDBFKBSC217000", start_period = "2000-01-01") # Austrian imports and exports of goods from/to Germany, 2002–2012, annual frequency: onb_data(hier_id = 901, key = "VDBQZA1000", start_period = 2002, end_period = 2012, freq = "A") # Number of Austrian banks' subsidiaries abroad and in the EU, from 2005, semiannual: onb_data( hier_id = 321, key = c("VDBKISDANZTAU", "VDBKISDANZTEU"), start_period = 200501, freq = "H" )
Fetch Österreichische Nationalbank (OeNB) dimension
onb_dimension(hier_id, key, lang = "en")onb_dimension(hier_id, key, lang = "en")
hier_id |
( |
key |
( |
lang |
( |
A data.table::data.table() with the requested data.
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
onb_dimension(hier_id = 11, key = "VDBFKBSC217000")onb_dimension(hier_id = 11, key = "VDBFKBSC217000")
Fetch Österreichische Nationalbank (OeNB) data frequency
onb_frequency(hier_id, key, ..., lang = "en")onb_frequency(hier_id, key, ..., lang = "en")
hier_id |
( |
key |
( |
... |
( |
lang |
( |
A data.table::data.table() with the requested data.
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
onb_frequency(hier_id = 74, key = "VDBOSBHAGBSTIN") onb_frequency(hier_id = 11, key = "VDBFKBSC217000")onb_frequency(hier_id = 74, key = "VDBOSBHAGBSTIN") onb_frequency(hier_id = 11, key = "VDBFKBSC217000")
Fetch Österreichische Nationalbank (OeNB) hierarchy
onb_hierarchy(hier_id, lang = "en")onb_hierarchy(hier_id, lang = "en")
hier_id |
( |
lang |
( |
A data.table::data.table() with the requested data.
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
onb_hierarchy(hier_id = 11)onb_hierarchy(hier_id = 11)
Fetch Österreichische Nationalbank (OeNB) metadata
onb_metadata(hier_id, key, ..., lang = "en")onb_metadata(hier_id, key, ..., lang = "en")
hier_id |
( |
key |
( |
... |
( |
lang |
( |
A data.table::data.table() with the requested data.
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
onb_metadata(hier_id = 11, key = "VDBFKBSC217000")onb_metadata(hier_id = 11, key = "VDBFKBSC217000")
Fetch Österreichische Nationalbank (OeNB) table of contents
onb_toc(lang = "en")onb_toc(lang = "en")
lang |
( |
A data.table::data.table() with the requested data.
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
onb_toc()onb_toc()
Retrieve time series data from the SNB data portal.
snb_data(key, start_date = NULL, end_date = NULL, lang = "en")snb_data(key, start_date = NULL, end_date = NULL, lang = "en")
key |
( |
start_date |
( |
end_date |
( |
lang |
( |
A data.table::data.table() with the requested data.
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
srb_cross_rates(),
srb_data()
snb_data("rendopar") # or filter for date range snb_data("rendopar", "2020-01-01", "2020-12-31")snb_data("rendopar") # or filter for date range snb_data("rendopar", "2020-01-01", "2020-12-31")
Retrieve the dimension structure for a given cube from the SNB data portal.
snb_dimension(key, lang = "en")snb_dimension(key, lang = "en")
key |
( |
lang |
( |
A data.table::data.table() with the dimension structure.
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
snb_dimension("rendopar")snb_dimension("rendopar")
Retrieve cube-level metadata (title, frequency, source, publication date) from the SNB data portal.
snb_metadata(key, lang = "en")snb_metadata(key, lang = "en")
key |
( |
lang |
( |
A single-row data.table::data.table() with columns:
key |
The cube key |
title |
The cube title |
sub_title |
The cube subtitle |
publishing_title |
The publishing section title |
public_since_date |
The first publication date |
frequency |
The frequency specification (e.g., |
source |
The data source |
has_multiple_sources |
Whether the cube has multiple sources |
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_toc(),
srb_calendar(),
srb_series()
snb_metadata("rendopar")snb_metadata("rendopar")
Retrieve the publication topic tree from the SNB data portal, listing the cubes and charts available under each topic.
snb_toc(lang = "en")snb_toc(lang = "en")
lang |
( |
A data.table::data.table() with one row per topic node and columns:
topic_id |
The top-level topic id |
topic |
The top-level topic title |
sub_topic |
The sub-topic title |
cube_id |
The associated cube id (if any) |
chart_id |
The associated chart id (if any) |
doc_id |
The associated documentation id (if any) |
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
srb_calendar(),
srb_series()
snb_toc()snb_toc()
Retrieve Swedish banking calendar information from the Sveriges Riksbank SWEA API.
srb_calendar(start_date, end_date = NULL)srb_calendar(start_date, end_date = NULL)
start_date |
( |
end_date |
( |
A data.table::data.table() with the calendar day information.
https://developer.api.riksbank.se/
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_series()
srb_calendar("2024-01-01", "2024-01-31")srb_calendar("2024-01-01", "2024-01-31")
Compute cross exchange rates between two currency series from the Sveriges Riksbank SWEA API.
srb_cross_rates(series1, series2, start_date, end_date = NULL)srb_cross_rates(series1, series2, start_date, end_date = NULL)
series1 |
( |
series2 |
( |
start_date |
( |
end_date |
( |
A data.table::data.table() with the cross rate data.
https://developer.api.riksbank.se/
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_data()
# USD/EUR cross rate srb_cross_rates("SEKUSDPMI", "SEKEURPMI", start_date = "2024-01-01", end_date = "2024-01-31")# USD/EUR cross rate srb_cross_rates("SEKUSDPMI", "SEKEURPMI", start_date = "2024-01-01", end_date = "2024-01-31")
Retrieve time series data from the Sveriges Riksbank SWEA API.
srb_data(series, start_date = NULL, end_date = NULL)srb_data(series, start_date = NULL, end_date = NULL)
series |
( |
start_date |
( |
end_date |
( |
A data.table::data.table() with the requested data.
https://developer.api.riksbank.se/
Other data:
bbk_data(),
bbk_series(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates()
# fetch USD/SEK exchange rate srb_data("SEKUSDPMI", start_date = "2024-01-01") # fetch EUR/SEK exchange rate srb_data("SEKEURPMI", start_date = "2024-01-01")# fetch USD/SEK exchange rate srb_data("SEKUSDPMI", start_date = "2024-01-01") # fetch EUR/SEK exchange rate srb_data("SEKEURPMI", start_date = "2024-01-01")
Retrieve available series or group metadata from the Sveriges Riksbank SWEA API.
srb_series(type = "series")srb_series(type = "series")
type |
( |
A data.table::data.table() with the requested metadata.
https://developer.api.riksbank.se/
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar()
srb_series()srb_series()